# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2025-02-13

### Added
- Add docstring example by @ddkasa
- Add badges by @ddkasa
- Add default message argument by @ddkasa

### Changed
- Allow picking the end date first by @ddkasa
- Rename dialogs to overlays by @ddkasa
- Switch all SystemDateTime to LocalDateTime by @ddkasa
- Use a datetime format for parsing by @ddkasa
- Verify edge cases by @ddkasa
- Verify edge cases by @ddkasa
- Move directions alias by @ddkasa
- Correct workflow name by @ddkasa
- Use add method for location reactive by @ddkasa
- Update default & clear action functionality by @ddkasa
- Use a base method for expand button by @ddkasa
- Update default & clear action functionality by @ddkasa
- Make reactive typing more consistent by @ddkasa
- Use dedicated target button by @ddkasa
- Use first row for aligning only by @ddkasa
- Simplify some typing by @ddkasa
- Rename binding by @ddkasa
- Use max unicode 1.1 icons by @ddkasa

### Fixed
- Deal with year edge cases by @ddkasa
- Lock button using click method by @ddkasa
- Wrong reactive bound to overlay by @ddkasa
- Update snapshots by @ddkasa
- Adjust keyboard month navigation by @ddkasa

### Removed
- Remove unnecessary action by @ddkasa
- Remove unused placeholder class by @ddkasa

## [0.1.0] - 2025-02-09

### Added
- Add publish ci workflow by @ddkasa
- Add release workflow by @ddkasa
- Add tests gh workflow by @ddkasa
- Add noxfile by @ddkasa
- Add yaml config by @ddkasa
- Add coverage dependencies by @ddkasa
- Add pytest xdist dep by @ddkasa
- Add snapshot report to ignore file by @ddkasa
- Add .nvim.lua file by @ddkasa
- Add py.typed file by @ddkasa
- Add extra testing dependencies by @ddkasa
- Add module __init__ file by @ddkasa
- Add about module by @ddkasa
- Added whenever by @ddkasa
- Add license file by @ddkasa

### Changed
- V0.1.0 release by @ddkasa
- Update configuration for publish by @ddkasa
- Setup git cliff changelog by @ddkasa
- Write readme document by @ddkasa
- Implement activity heatmap by @ddkasa
- Change max line length by @ddkasa
- Implement helper functionality by @ddkasa
- Supplementary widgets by @ddkasa
- Pytest config by @ddkasa
- Import pickers into base module by @ddkasa
- Implement timerange picker classes by @ddkasa
- Implement datetime picker classes by @ddkasa
- Implement time & duration picker classes by @ddkasa
- Implement date picker classes by @ddkasa
- Implement base picker classes by @ddkasa
- Implement demo app by @ddkasa
- Improve project configuration by @ddkasa
- Init commit by @ddkasa

### Fixed
- Implement freeze_time fixture by @ddkasa
- Implement test app fixture by @ddkasa

## New Contributors
* @ddkasa made their first contribution
[0.2.0]: https://github.com/ddkasa/textual-timepiece/compare/v0.1.0..0.2.0

<!-- generated by git-cliff -->
